@@ -2,7 +2,6 @@
 An Abode alarm Python library.
 """
 
-import json
 import logging
 import os
 
@@ -111,10 +110,8 @@ class Abode:
             login_data['remember_me'] = 1
 
         response = self._session.post(CONST.LOGIN_URL, json=login_data)
-
         AbodeAuthenticationException.raise_for(response)
-
-        response_object = json.loads(response.text)
+        response_object = response.json()
 
         # Check for multi-factor authentication
         if 'mfa_type' in response_object:
@@ -130,8 +127,7 @@ class Abode:
 
         oauth_response = self._session.get(CONST.OAUTH_TOKEN_URL)
         AbodeAuthenticationException.raise_for(oauth_response)
-
-        oauth_response_object = json.loads(oauth_response.text)
+        oauth_response_object = oauth_response.json()
 
         _LOGGER.debug("Login Response: %s", response.text)
 
@@ -173,65 +169,62 @@ class Abode:
         self.get_devices(refresh=True)
         self.get_automations(refresh=True)
 
-    def get_devices(self, refresh=False, generic_type=None):  # noqa: C901
+    def get_devices(self, refresh=False, generic_type=None):
         """Get all devices from Abode."""
         if refresh or self._devices is None:
-            if self._devices is None:
-                self._devices = {}
+            self._load_devices()
 
-            _LOGGER.info("Updating all devices...")
-            response = self.send_request("get", CONST.DEVICES_URL)
-            response_object = json.loads(response.text)
+        return [
+            device
+            for device in self._devices.values()
+            if not generic_type or device.generic_type == generic_type
+        ]
 
-            if response_object and not isinstance(response_object, (tuple, list)):
-                response_object = [response_object]
+    def _load_devices(self):
+        if self._devices is None:
+            self._devices = {}
 
-            _LOGGER.debug("Get Devices Response: %s", response.text)
+        _LOGGER.info("Updating all devices...")
+        response = self.send_request("get", CONST.DEVICES_URL)
+        response_object = response.json()
 
-            for device_json in response_object:
-                # Attempt to reuse an existing device
-                device = self._devices.get(device_json['id'])
+        if response_object and not isinstance(response_object, (tuple, list)):
+            response_object = [response_object]
 
-                # No existing device, create a new one
-                if device:
-                    device.update(device_json)
-                else:
-                    device = new_device(device_json, self)
+        _LOGGER.debug("Get Devices Response: %s", response.text)
 
-                    if not device:
-                        _LOGGER.debug("Skipping unknown device: %s", device_json)
+        for device_json in response_object:
+            # Attempt to reuse an existing device
+            device = self._devices.get(device_json['id'])
 
-                        continue
-
-                    self._devices[device.device_id] = device
-
-            # We will be treating the Abode panel itself as an armable device.
-            panel_response = self.send_request("get", CONST.PANEL_URL)
-            panel_json = json.loads(panel_response.text)
-
-            self._panel.update(panel_json)
-
-            _LOGGER.debug("Get Mode Panel Response: %s", response.text)
-
-            alarm_device = self._devices.get(CONST.ALARM_DEVICE_ID + '1')
-
-            if alarm_device:
-                alarm_device.update(self._panel)
+            # No existing device, create a new one
+            if device:
+                device.update(device_json)
             else:
-                alarm_device = ALARM.create_alarm(self._panel, self)
-                self._devices[alarm_device.device_id] = alarm_device
+                device = new_device(device_json, self)
 
-        if generic_type:
-            devices = []
-            for device in self._devices.values():
-                if (
-                    device.generic_type is not None
-                    and device.generic_type in generic_type
-                ):
-                    devices.append(device)
-            return devices
+                if not device:
+                    _LOGGER.debug("Skipping unknown device: %s", device_json)
 
-        return list(self._devices.values())
+                    continue
+
+                self._devices[device.device_id] = device
+
+        # We will be treating the Abode panel itself as an armable device.
+        panel_response = self.send_request("get", CONST.PANEL_URL)
+        panel_json = panel_response.json()
+
+        self._panel.update(panel_json)
+
+        _LOGGER.debug("Get Mode Panel Response: %s", response.text)
+
+        alarm_device = self._devices.get(CONST.ALARM_DEVICE_ID + '1')
+
+        if alarm_device:
+            alarm_device.update(self._panel)
+        else:
+            alarm_device = ALARM.create_alarm(self._panel, self)
+            self._devices[alarm_device.device_id] = alarm_device
 
     def get_device(self, device_id, refresh=False):
         """Get a single device."""
@@ -255,7 +248,7 @@ class Abode:
 
             _LOGGER.info("Updating all automations...")
             response = self.send_request("get", CONST.AUTOMATION_URL)
-            response_object = json.loads(response.text)
+            response_object = response.json()
 
             if response_object and not isinstance(response_object, (tuple, list)):
                 response_object = [response_object]
@@ -290,10 +283,6 @@ class Abode:
 
     def get_alarm(self, area='1', refresh=False):
         """Shortcut method to get the alarm device."""
-        if self._devices is None:
-            self.get_devices()
-            refresh = False
-
         return self.get_device(CONST.ALARM_DEVICE_ID + area, refresh)
 
     def set_default_mode(self, default_mode):
