@@ -1,5 +1,5 @@
 """Abode camera device."""
-import json
+import base64
 import logging
 from shutil import copyfileobj
 import requests
@@ -17,15 +17,16 @@ class AbodeCamera(AbodeDevice):
     """Class to represent a camera device."""
 
     _image_url = None
+    _snapshot_base64 = None
 
     def capture(self):
         """Request a new camera image."""
         # Abode IP cameras use a different URL for image captures.
         if 'control_url_snapshot' in self._json_state:
-            url = CONST.BASE_URL + self._json_state['control_url_snapshot']
+            url = self._json_state['control_url_snapshot']
 
         elif 'control_url' in self._json_state:
-            url = CONST.BASE_URL + self._json_state['control_url']
+            url = self._json_state['control_url']
 
         else:
             raise AbodeException(ERROR.MISSING_CONTROL_URL)
@@ -49,7 +50,7 @@ class AbodeCamera(AbodeDevice):
 
         _LOGGER.debug("Get image response: %s", response.text)
 
-        return self.update_image_location(json.loads(response.text))
+        return self.update_image_location(response.json())
 
     def update_image_location(self, timeline_json):
         """Update the image location."""
@@ -74,8 +75,7 @@ class AbodeCamera(AbodeDevice):
 
         # Perform a "head" request for the image and look for a
         # 302 Found response
-        url = CONST.BASE_URL + file_path
-        response = self._abode.send_request("head", url)
+        response = self._abode.send_request("head", file_path)
 
         if response.status_code != 302:
             _LOGGER.warning(
@@ -116,6 +116,47 @@ class AbodeCamera(AbodeDevice):
 
         return True
 
+    def snapshot(self):
+        """Request the current camera snapshot as a base64-encoded string."""
+        url = f"{CONST.CAMERA_INTEGRATIONS_URL}{self._device_uuid}/snapshot"
+
+        try:
+            response = self._abode.send_request("post", url)
+            _LOGGER.debug("Camera snapshot response: %s", response.text)
+        except AbodeException as exc:
+            _LOGGER.warning("Failed to get camera snapshot image: %s", exc)
+            return False
+
+        self._snapshot_base64 = response.json().get("base64Image")
+        if self._snapshot_base64 is None:
+            _LOGGER.warning("Camera snapshot data missing")
+            return False
+
+        return True
+
+    def snapshot_to_file(self, path, get_snapshot=True):
+        """Write the snapshot image to a file."""
+        if not self._snapshot_base64 or get_snapshot:
+            if not self.snapshot():
+                return False
+
+        try:
+            with open(path, "wb") as imgfile:
+                imgfile.write(base64.b64decode(self._snapshot_base64))
+        except OSError as exc:
+            _LOGGER.warning("Failed to write snapshot image to file: %s", exc)
+            return False
+
+        return True
+
+    def snapshot_data_url(self, get_snapshot=True):
+        """Return the snapshot image as a data url."""
+        if not self._snapshot_base64 or get_snapshot:
+            if not self.snapshot():
+                return ""
+
+        return f"data:image/jpeg;base64,{self._snapshot_base64}"
+
     def privacy_mode(self, enable):
         """Set camera privacy mode (camera on/off)."""
         if self._json_state['privacy']:
@@ -133,7 +174,7 @@ class AbodeCamera(AbodeDevice):
             response = self._abode.send_request(
                 method="put", path=path, data=camera_data
             )
-            response_object = json.loads(response.text)
+            response_object = response.json()
 
             _LOGGER.debug("Camera Privacy Mode Response: %s", response.text)
 
