@@ -5,12 +5,12 @@ import jaraco.abode
 import jaraco.abode.helpers.constants as CONST
 import pytest
 
-import tests.mock as MOCK
-import tests.mock.login as LOGIN
-import tests.mock.oauth_claims as OAUTH_CLAIMS
-import tests.mock.logout as LOGOUT
-import tests.mock.panel as PANEL
-import tests.mock.automation as AUTOMATION
+from . import mock as MOCK
+from .mock import login as LOGIN
+from .mock import oauth_claims as OAUTH_CLAIMS
+from .mock import logout as LOGOUT
+from .mock import panel as PANEL
+from .mock import automation as AUTOMATION
 
 
 AID_1 = '47fae27488f74f55b964a81a066c3a01'
